==> open-xchange-mobile-api-facade_1.0.25.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.25/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Attachment.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import com.openexchange.mobile.api.facade.connectors.responses.mtos.AttachmentMto;

import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
public class Attachment {

    public enum Disposition {
        NONE("none"),
        ATTACHMENT("attachment"),
        INLINE("inline");

        private String value;

        Disposition(String value) {
            if (value == null) {
                throw new IllegalArgumentException("Disposition enum needs a value");
            }
            this.value = value;
        }

        public static Disposition from(String value) {
            for (Disposition disposition : values()) {
                if (disposition.value.equalsIgnoreCase(value)) {
                    return disposition;
                }
            }
            return NONE;
        }

        public String getValue() {
            return value;
        }
    }

    private final String id;

    private final Disposition disposition;

    private final String contentType;

    private final Integer size;

    private String content;

    private final boolean truncated;

    private final String filename;

    private final String cid;

    private String downloadUrl;

    public Attachment(AttachmentMto attachmentMto) {
        this.id = attachmentMto.getId();
        this.disposition = Disposition.from(attachmentMto.getDisposition());
        this.contentType = attachmentMto.getContentType();
        this.size = attachmentMto.getSize();
        this.content = attachmentMto.getContent();
        this.truncated = attachmentMto.isTruncated();
        this.filename = attachmentMto.getFilename();
        this.cid = attachmentMto.getCid();
    }

}

==> open-xchange-mobile-api-facade_1.2.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Attachment.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import com.openexchange.mobile.api.facade.connectors.responses.mtos.AttachmentMto;

import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
public class Attachment {

    public enum Disposition {
        NONE("none"),
        ATTACHMENT("attachment"),
        INLINE("inline");

        private String value;

        Disposition(String value) {
            if (value == null) {
                throw new IllegalArgumentException("Disposition enum needs a value");
            }
            this.value = value;
        }

        public static Disposition from(String value) {
            for (Disposition disposition : values()) {
                if (disposition.value.equalsIgnoreCase(value)) {
                    return disposition;
                }
            }
            return NONE;
        }

        public String getValue() {
            return value;
        }
    }

    private final String id;

    private final Disposition disposition;

    private final String contentType;

    private final Integer size;

    private String content;

    private final Boolean truncated;

    private final String filename;

    private final String cid;

    private String downloadUrl;

    public Attachment(AttachmentMto attachmentMto) {
        this.id = attachmentMto.getId();
        this.disposition = Disposition.from(attachmentMto.getDisposition());
        this.contentType = attachmentMto.getContentType();
        this.size = attachmentMto.getSize();
        this.content = attachmentMto.getContent();
        this.truncated = attachmentMto.isTruncated() ? Boolean.TRUE : null;
        this.filename = attachmentMto.getFilename();
        this.cid = attachmentMto.getCid();
    }

}
